@@ -1,11 +1,10 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 use super::{
     helpers::{div_or, pluralize, processed_files_err_report, prompt_user},
@@ -103,7 +102,7 @@ impl Default for ProgressIndicator {
 
 // processes the `safe files get` command.  called by files.rs
 //
-// dest is a local path.  defaults to "."
+// dst is a local path.  defaults to "."
 //   Path will be created if not existing, else error.
 //
 // TODO: _preserve file attributes is not yet implemented, we need them
@@ -121,13 +120,13 @@ impl Default for ProgressIndicator {
 pub async fn process_get_command(
     safe: &mut Safe,
     source: XorUrl,
-    dest: Option<String>,
+    dst: Option<String>,
     exists: FileExistsAction,
     progress: ProgressIndicator,
     _preserve: bool,
     _output_fmt: OutputFmt,
 ) -> Result<()> {
-    let str_path = dest.unwrap_or_else(|| ".".to_string());
+    let str_path = dst.unwrap_or_else(|| ".".to_string());
     let path = Path::new(&str_path);
 
     let mut overwrites: u64 = 0;
@@ -139,7 +138,7 @@ pub async fn process_get_command(
             let mut mystatus = status.clone();
 
             if status.file_bytes_written == 0 {
-                // It is an error/warning if the dest path attempts to use
+                // It is an error/warning if the dst path attempts to use
                 // an existing file as a directory. But other files should
                 // still be written.  eg:
                 // $ mkdir -p /tmp/a/b/c && touch /tmp/a/file.txt
@@ -180,10 +179,7 @@ pub async fn process_get_command(
                         FileExistsAction::Overwrite => true,
                         FileExistsAction::Preserve => false,
                         FileExistsAction::Ask => {
-                            let prompt = format!(
-                                "overwrite '{}'? ",
-                                status.path_local.display().to_string()
-                            );
+                            let prompt = format!("overwrite '{}'? ", status.path_local.display());
                             prompt_yes_no(&prompt, "Y")
                         }
                     };
@@ -334,7 +330,7 @@ async fn files_container_get_files(
         SafeData::FilesContainer {
             version, files_map, ..
         } => (version.map_or("".to_string(), |v| v.to_string()), files_map),
-        SafeData::PublicBlob { metadata, .. } => {
+        SafeData::PublicFile { metadata, .. } => {
             if let Some(file_item) = metadata {
                 let mut files_map = FilesMap::new();
                 files_map.insert("".to_string(), file_item);
@@ -372,7 +368,7 @@ async fn files_container_get_files(
 // The root path is determined as per the follow matrix:
 /*
 
-source     |source type| dest                      | dest exists | dest type | translated
+source     |source type| dst                      | dst exists | dst type | translated
 ---------------------------------------------------------------------------------------
 testdata   | dir       | /tmp/testdata             | Y           | dir       | /tmp/testdata/testdata
 testdata   | dir       | /tmp/testdata             | Y           | file      | error:  cannot overwrite non-directory '/tmp/testdata' with directory './testdata/'
@@ -619,7 +615,7 @@ fn denormalize_slashes(p: &str) -> String {
 }
 
 // Downloads a file from the network to a given file path
-// xorurl must point to a Blob
+// xorurl must point to a file
 // size (in bytes) must be provided
 async fn download_file_from_net(
     safe: &mut Safe,
@@ -640,7 +636,7 @@ async fn download_file_from_net(
     let mut stream = BufWriter::new(fh);
 
     // gets public or private, based on xorurl type
-    let filedata = files_get_blob(safe, xorurl, None).await?;
+    let filedata = files_get(safe, xorurl, None).await?;
     bytes_written += stream_write(&mut stream, &filedata, path)? as u64;
     rcvd += filedata.len() as u64;
     trace!("received {} bytes of {}", rcvd, size,);
@@ -691,13 +687,13 @@ fn create_dir_all(dir_path: &Path) -> Result<()> {
         .with_context(|| format!("Couldn't create path: \"{}\"", dir_path.display(),))
 }
 
-/// # Get Public or Private Blob
-/// Get immutable data blobs from the network.
-pub async fn files_get_blob(safe: &mut Safe, url: &str, range: Range) -> Result<Vec<u8>> {
+/// # Get Public or Private file
+/// Get immutable files from the network.
+pub async fn files_get(safe: &mut Safe, url: &str, range: Range) -> Result<Vec<u8>> {
     match SafeUrl::from_url(url)?.data_type() {
-        DataType::Bytes => {
-            let pub_blob = safe.files_get_public_data(url, range).await?;
-            Ok(pub_blob.chunk().to_vec())
+        DataType::File => {
+            let bytes = safe.files_get_public(url, range).await?;
+            Ok(bytes.chunk().to_vec())
         }
         _ => Err(eyre!("URL target is not immutable data")),
     }
