@@ -1,11 +1,10 @@
-// Copyright 2020 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
-// This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
-// http://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
-// https://opensource.org/licenses/BSD-3-Clause>, at your option. This file may not be copied,
-// modified, or distributed except according to those terms. Please review the Licences for the
-// specific language governing permissions and limitations relating to use of the SAFE Network
-// Software.
+// This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
+// Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
+// under the GPL Licence is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+// KIND, either express or implied. Please review the Licences for the specific language governing
+// permissions and limitations relating to use of the SAFE Network Software.
 
 use assert_cmd::prelude::*;
 use assert_fs::prelude::*;
@@ -98,7 +97,7 @@ fn calling_safe_files_put_recursive() -> Result<()> {
 }
 
 #[test]
-fn calling_safe_files_put_recursive_and_set_dest_path() -> Result<()> {
+fn calling_safe_files_put_recursive_and_set_dst_path() -> Result<()> {
     let files_container = safe_cmd_stdout(
         ["files", "put", TEST_FOLDER, "/aha", "--recursive"],
         Some(0),
@@ -521,7 +520,7 @@ fn calling_files_sync_and_fetch_with_nrsurl_and_nrs_update() -> Result<()> {
 
     //// but in version 0 of the NRS name it should still link to version 0 of the FilesContainer
     //// where all files should still be there
-    let versioned_nrsurl = format!("{}?v={}", nrsurl, nrs_version.to_string());
+    let versioned_nrsurl = format!("{}?v={}", nrsurl, nrs_version);
     let output = safe_cmd_stdout(["cat", &versioned_nrsurl, "--json"], Some(0))?;
     let (xorurl, files_map) = parse_files_container_output(&output)?;
     assert_eq!(xorurl, versioned_nrsurl);
@@ -970,19 +969,35 @@ fn calling_files_tree() -> Result<()> {
     assert_eq!(root["sub"][1]["name"], ".subhidden");
     assert_eq!(root["sub"][1]["details"]["type"], "inode/directory");
     assert_eq!(root["sub"][1]["sub"][0]["name"], "test.md");
+
+    // It seems to be possible for the sizes of files to vary based on the the OS they were
+    // uploaded from, so we won't hard code the values.
+    let another_file_len = get_file_len("../resources/testdata/another.md")?;
     assert_eq!(root["sub"][2]["name"], "another.md");
-    assert_eq!(root["sub"][2]["details"]["size"], "6");
+    assert_eq!(
+        root["sub"][2]["details"]["size"],
+        another_file_len.to_string()
+    );
     assert_eq!(root["sub"][2]["details"]["type"], "text/markdown");
+
     assert_eq!(root["sub"][3]["name"], "emptyfolder");
     assert_eq!(root["sub"][3]["details"]["size"], "0");
     assert_eq!(root["sub"][3]["details"]["type"], "inode/directory");
 
+    let markdown_file_len = get_file_len("../resources/testdata/large_markdown_file.md")?;
     assert_eq!(root["sub"][4]["name"], "large_markdown_file.md");
-    assert_eq!(root["sub"][4]["details"]["size"], "95864");
+    assert_eq!(
+        root["sub"][4]["details"]["size"],
+        markdown_file_len.to_string()
+    );
     assert_eq!(root["sub"][4]["details"]["type"], "text/markdown");
 
+    let noextension_file_len = get_file_len("../resources/testdata/noextension")?;
     assert_eq!(root["sub"][5]["name"], "noextension");
-    assert_eq!(root["sub"][5]["details"]["size"], "20");
+    assert_eq!(
+        root["sub"][5]["details"]["size"],
+        noextension_file_len.to_string()
+    );
     assert_eq!(root["sub"][5]["details"]["type"], "Raw");
     assert_eq!(root["sub"][6]["name"], "subfolder");
     assert_eq!(root["sub"][6]["sub"][0]["name"], "sub2.md");
